@@ -1,5 +1,3 @@
-from roiextractors import CaimanSegmentationExtractor
-
 from ..basesegmentationextractorinterface import BaseSegmentationExtractorInterface
 from ....utils import FilePathType
 
@@ -7,7 +5,6 @@ from ....utils import FilePathType
 class CaimanSegmentationInterface(BaseSegmentationExtractorInterface):
     """Data interface for CaimanSegmentationExtractor."""
 
-    SegX = CaimanSegmentationExtractor
-
-    def __init__(self, file_path: FilePathType):
+    def __init__(self, file_path: FilePathType, verbose: bool = True):
         super().__init__(file_path=file_path)
+        self.verbose = verbose
