@@ -1,5 +1,3 @@
-from roiextractors import SbxImagingExtractor
-
 from ..baseimagingextractorinterface import BaseImagingExtractorInterface
 from ....utils import FilePathType, FloatType
 
@@ -7,8 +5,6 @@ from ....utils import FilePathType, FloatType
 class SbxImagingInterface(BaseImagingExtractorInterface):
     """Data Interface for SbxImagingExtractor."""
 
-    IX = SbxImagingExtractor
-
     def __init__(self, file_path: FilePathType, sampling_frequency: FloatType = None, verbose: bool = True):
         super().__init__(file_path=file_path, sampling_frequency=sampling_frequency, verbose=verbose)
 
